@@ -34,7 +34,7 @@ def confirmation_prompt(question):
 def fetch_remote_git_yaml(remote_url, git_ref, file_path):
     cmd = "git archive --remote={} {} {} | tar -xO".format(remote_url, git_ref, file_path)
     file_str = check_output(cmd, shell=True).decode()
-    return yaml.load(file_str)
+    return yaml.full_load(file_str)
 
 
 def fetch_git_yaml(relpath, git_ref):
@@ -46,11 +46,11 @@ def fetch_git_yaml(relpath, git_ref):
         for fetch_info in repo.remotes["origin"].fetch():
             _logger.info("\tUpdated %s to %s" % (fetch_info.ref, fetch_info.commit))
         model_str = repo.git.show("{}:{}".format(git_ref, git_path))
-        return yaml.load(model_str)
+        return yaml.full_load(model_str)
     else:
         with open(relpath, "r") as f:
             _logger.info("Using {} from current working directory".format(relpath))
-            return yaml.load(f)
+            return yaml.full_load(f)
 
 
 def confirm_git_branch(work_dir, nomitall):
@@ -209,11 +209,11 @@ def model_update(
         nomitall_url = "https://staging.api.nomnomdata.com/api/1"
     else:
         nomitall_url = nomitall
-    icons = doc.pop("icons", {})
     process_help(nomitall_url, doc, nomitall_secret, doc["uuid"])
-    update_engine(nomitall_url, doc, model_type, nomitall_secret)
+    icons = doc.pop("icons", {})
     if model_type == "engine":
         upload_icons(nomitall_url, icons, nomitall_secret, doc["uuid"])
+    update_engine(nomitall_url, doc, model_type, nomitall_secret)
 
 
 def upload_icons(nomitall_url, icons, nomitall_secret, uuid):
@@ -249,11 +249,13 @@ def process_help(nomitall_url, doc, nomitall_secret, uuid, key="root"):
         for k, subele in doc.items():
             if k == "help":
                 if "file" in subele:
+                    if "name" in doc:
+                        key += "." + doc["name"]
                     upload_help(nomitall_url, nomitall_secret, uuid, key, subele["file"])
                     doc[k] = {"key": key}
             else:
                 process_help(
-                    nomitall_secret, subele, nomitall_secret, uuid, key=".".join([key, k])
+                    nomitall_url, subele, nomitall_secret, uuid, key=".".join([key, k]),
                 )
 
 
@@ -270,15 +272,17 @@ def update_engine(nomitall_url, model, model_type, nomitall_secret):
 
 
 def check_response(resp):
-    if resp.status_code == 500:
-        _logger.error(f"Internal server error\n{resp.text}")
-        return
-    reply_data = resp.json()
-    if reply_data.get("error"):
-        raise Exception(str(reply_data))
-    if reply_data.get("status"):
-        if reply_data["status"] == "success":
-            _logger.info("Request successful")
-    if resp.status_code == 401:
-        _logger.error(f"Check secret key is valid\n\t\t {resp.json()}")
+    if not resp.ok:
+        if resp.status_code == 500:
+            _logger.error(f"Internal server error\n{resp.text}")
+            raise click.Abort
+        reply_data = resp.json()
+        if reply_data.get("error"):
+            raise click.Abort(str(reply_data))
+        if reply_data.get("status"):
+            if reply_data["status"] == "success":
+                _logger.info("Request successful")
+        if resp.status_code == 401:
+            _logger.error(f"Check secret key is valid\n\t\t {resp.json()}")
+            raise click.Abort
     resp.raise_for_status()
